summaryrefslogtreecommitdiff
path: root/lib/language.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/language.php')
-rw-r--r--lib/language.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/language.php b/lib/language.php
index 9ad2d31bd..561a4ddb8 100644
--- a/lib/language.php
+++ b/lib/language.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* utility functions for i18n
*
@@ -20,15 +20,15 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category I18n
- * @package Laconica
+ * @package StatusNet
* @author Matthew Gregg <matthew.gregg@gmail.com>
* @author Ciaran Gultnieks <ciaran@ciarang.com>
- * @author Evan Prodromou <evan@controlyourself.ca>
+ * @author Evan Prodromou <evan@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* utility functions for i18n